pub enum IntegerDecodingError {
TooManyOctets,
ValueTooLarge,
NotEnoughOctets,
InvalidPrefix,
}Expand description
Represents all errors that can be encountered while decoding an integer.
Variants
TooManyOctets
5.1. specifies that “excessively large integer decodings” MUST be considered an error (whether the size is the number of octets or value). This variant corresponds to the encoding containing too many octets.
ValueTooLarge
The variant corresponds to the case where the value of the integer being decoded exceeds a certain threshold.
NotEnoughOctets
When a buffer from which an integer was supposed to be encoded does not contain enough octets to complete the decoding.
InvalidPrefix
Only valid prefixes are [1, 8]